@@ -634,16 +634,20 @@ gpk_strv_join_locale (gchar **array)
 	if (length == 1)
 		return g_strdup (array[0]);
 	else if (length == 2)
+                /* Translators: a list of two things */
 		return g_strdup_printf (_("%s and %s"),
 					array[0], array[1]);
 	else if (length == 3)
+                /* Translators: a list of three things */
 		return g_strdup_printf (_("%s, %s and %s"),
 					array[0], array[1], array[2]);
 	else if (length == 4)
+                /* Translators: a list of four things */
 		return g_strdup_printf (_("%s, %s, %s and %s"),
 					array[0], array[1],
 					array[2], array[3]);
 	else if (length == 5)
+                /* Translators: a list of five things */
 		return g_strdup_printf (_("%s, %s, %s, %s and %s"),
 					array[0], array[1], array[2],
 					array[3], array[4]);
@@ -776,43 +780,6 @@ gpk_package_entry_completion_new (void)
 	return completion;
 }
 
-/**
- * gpk_ignore_session_error:
- *
- * Returns true if the error is a remote exception where we canceled
- **/
-gboolean
-gpk_ignore_session_error (GError *error)
-{
-	gboolean ret = FALSE;
-	const gchar *name;
-
-	if (error == NULL)
-		goto out;
-	if (error->domain != DBUS_GERROR)
-		goto out;
-	if (error->code != DBUS_GERROR_REMOTE_EXCEPTION)
-		goto out;
-
-	/* use one of our local codes */
-	name = dbus_g_error_get_name (error);
-	if (name == NULL)
-		goto out;
-
-	if (g_str_has_prefix (name, "org.freedesktop.PackageKit.Modify.Cancelled")) {
-		ret = TRUE;
-		goto out;
-	}
-
-	/* DBus-glib hates us */
-	if (g_str_has_prefix (name, "Org.freedesktop.PackageKit.Modify.Cancelled")) {
-		ret = TRUE;
-		goto out;
-	}
-out:
-	return ret;
-}
-
 /***************************************************************************
  ***                          MAKE CHECK TESTS                           ***
  ***************************************************************************/
